@@ -1,5 +1,5 @@
 """
-Asyncio client for Zyte Data API
+Asyncio client for Zyte API
 """
 
 import asyncio
@@ -63,7 +63,7 @@ class AsyncClient:
         retrying = retrying or zyte_api_retrying
         post = _post_func(session)
         auth = aiohttp.BasicAuth(self.api_key)
-        headers = {'User-Agent': user_agent(aiohttp)}
+        headers = {'User-Agent': user_agent(aiohttp), 'Accept-Encoding': 'br'}
 
         response_stats = []
         start_global = time.perf_counter()
@@ -114,14 +114,11 @@ class AsyncClient:
         try:
             # Try to make a request
             result = await request()
-            self.agg_stats.n_extracted_queries += 1
+            self.agg_stats.n_success += 1
         except Exception:
             self.agg_stats.n_fatal_errors += 1
             raise
-        finally:
-            self.agg_stats.n_input_queries += 1
 
-        self.agg_stats.n_results += 1
         return result
 
     def request_parallel_as_completed(self,
@@ -130,7 +127,7 @@ class AsyncClient:
                                       endpoint: str = 'extract',
                                       session: Optional[aiohttp.ClientSession] = None,
                                       ) -> Iterator[asyncio.Future]:
-        """ Send multiple requests to Zyte Data API in parallel.
+        """ Send multiple requests to Zyte API in parallel.
         Return an `asyncio.as_completed` iterator.
 
         ``queries`` is a list of requests to process (dicts).
